<?php

$mgrm_banners = new mgrm_banners;

class mgrm_banners {
	
	var $slug	= "banners";
	var $title	= "Bannières";
	
	var $min_rights		= 'delete_others_pages';
	var $max_rights		= 'activate_plugins';
	
	var $banner_w		= 1600;
	var $banner_h		= 560;
	var $banner_crop	= true;
	
	var $notice_title_empty		= '<p>Veuillez insérer un titre pour la bannière.</p>';
	var $notice_title_exists	= '<p>Une bannière avec le même nom existe déjà, veuillez en choisir un autre.</p>';
	var $notice_added			= '<p>Votre bannière a bien été ajoutée, vous pouvez maintenant la personnaliser.</p>';
	var $notice_deleted			= '<p>Votre bannière a bien été supprimée.</p>';
	
	var $cur_lng	= "";
	
	
	// Construction de la classe
	function __construct()
	{
		global $mgrm_lng;
		
		$this->cur_lng		= $mgrm_lng->cur_lng;
		
		add_image_size( 'mgrm_'.$this->slug, $this->banner_w, $this->banner_h, $this->banner_crop );
		
		if ( is_admin() )
		{
			// Ajouter la page d'admin
			add_action( 'admin_enqueue_scripts', array( $this, 'admin_js_css' ) );
			add_action( 'admin_menu', array( $this, 'add_admin_menu' ) );
		}
		
		add_action( 'wp_enqueue_scripts', array( $this, 'front_js_css' ) );
		add_action( 'mgrm_banner_display', array( $this, 'banner_display' ) );
	}
	
	// Ajoute le js et css
	function admin_js_css( $current_screen )
	{		
		if ( strstr( $current_screen, '_page_'.$this->slug )  !== false )
		{
			$path = get_template_directory_uri().'/custom/'.$this->slug;
			
			wp_enqueue_style( 'mgrm_'.$this->slug, $path.'/css/admin.css' );
			
			wp_enqueue_script('jquery');
			
			wp_enqueue_media();
			
			wp_enqueue_script( 'mgrm_'.$this->slug, $path.'/js/admin.js.php?bw='.$this->banner_w.'&bh='.$this->banner_h, array('jquery'), null, false );
		}
	}
	
	
	// Ajouter le menu dans l'admin
	function add_admin_menu ()
	{
		global $mgrm_infos;
		
		add_submenu_page( $mgrm_infos->slug, $this->title, $this->title, $this->min_rights, $this->slug, array( $this, "admin_page" ) );
	}
	
	
	// Affichage de la page d'admin
	function admin_page()
	{
		global $wp_query; 
		
		$message = '';
		
		// Appeler la fonction pour enregistrer les changements
		if ( isset( $_POST['action'] ) && $_POST['action'] == 'add' )
		{
			$message = $this->add_item();
			
		}else if ( isset( $_POST['action'] ) && $_POST['action'] == 'del' )
		{
			$message = $this->del_item();
			
		}else if ( isset( $_POST['action'] ) && $_POST['action'] == 'update' )
		{
			$message = $this->update_changes();
		}
		
		// Récupérer les données
		$options	= get_option( 'mgrm_'.$this->slug );
		$options	= json_decode( $options );
		
		// Variables url
		$page	= get_query_var( 'page', $this->slug );
		$b		= isset( $_GET['b'] ) && !empty( $_GET['b'] ) ? $_GET['b'] : '';
		
		// Récupérer les données du banner
		$banner_data	= "";
		if ( !empty( $b ) )
		{
			foreach( $options as $banner )
			{
				if ( $banner->slug == $b )
				{
					$banner_data	= $banner;
				}
			}
		}
		
		
		$show_on_all	= isset( $banner_data->show_on->{$this->cur_lng}->all ) ? $banner_data->show_on->{$this->cur_lng}->all : 0;
		$show_on_hp		= isset( $banner_data->show_on->{$this->cur_lng}->hp ) ? $banner_data->show_on->{$this->cur_lng}->hp : 0;
		$show_on_pid	= isset( $banner_data->show_on->{$this->cur_lng}->pid ) ? $banner_data->show_on->{$this->cur_lng}->pid : 0;
		$show_on_cid	= isset( $banner_data->show_on->{$this->cur_lng}->cid ) ? $banner_data->show_on->{$this->cur_lng}->cid : 0;
		
		
		//print "<pre>";
		//print_r( $banner_data );
		//print "</pre>";
		
		
		?>
		<div class="wrap">
			<h2><?php echo get_bloginfo( 'sitename' ); ?> - <small><?php echo $this->title; ?></small></h2>
			<br>
			<?php echo $message; ?>
				
			<?php // Afficher un message si vide
			if ( empty( $options ) ) : ?>
			<p>Désolé, il n'y a pas de banner disponible.</p>
			
			<?php // Sinon afficher le contenu
			else : ?>
			
				<?php // Afficher les images
				if ( !empty( $banner_data ) ) : ?>
				<form action="" method="post">
					<input type="hidden" value="update" name="action">
					<div id="titlediv">
						<div id="titlewrap">
							<input type="hidden" name="slug" value="<?php echo $banner_data->slug; ?>">
							<input type="text" id="title" name="title" value="<?php echo $banner_data->title; ?>" placeholder="Saisissez votre titre ici" disabled="disabled">
						</div>
						<br>
					</div>
					<div id="titlediv">
						<div id="titlewrap">
							<label>
							<input type="checkbox" name="show_on_all" value="1"<?php checked( 1, $show_on_all, 1 ); ?>>
							Afficher partout ou 
							<input type="checkbox" name="show_on_hp" value="1"<?php checked( 1, $show_on_hp, 1 ); ?>>
							Afficher sur la page d'accueil
							et/ou sur une page
							<?php
								$args = array(
									'depth'				=> 1,
									'selected'			=> $show_on_pid,
									'name'				=> 'show_on_pid',
									'show_option_none'	=> 'Choisissez',
									'option_none_value'	=> 0
								);
								wp_dropdown_pages( $args );	
							?>
							et/ou dans la catégorie 
							<?php
								$args = array(
									'depth'				=> 1,
									'selected'			=> $show_on_cid,
									'name'				=> 'show_on_cid',
									'show_option_none'	=> 'Choisissez',
									'option_none_value'	=> 0
								);
								wp_dropdown_categories( $args );	
							?>
							</label>
						</div>
						<br>
					</div>
					<table class="widefat" id="imgs-wrapper">
						<tbody>
							
							<?php
							if ( isset( $banner_data->images->{$this->cur_lng} ) && !empty( $banner_data->images->{$this->cur_lng} ) ) :
								
								$i=0;
								$img_count	= count( $banner_data->images->{$this->cur_lng} );
								
								$this->echo_img();
								$i=1;
								$img_count++;
								
								foreach( $banner_data->images->{$this->cur_lng} as $img )
								{	
									if ( isset( $img ) )
									{
										$args	= array(
											"img_id"		=> $img->id,
											"img_title"		=> $img->title,
											"img_url"		=> $img->url,
											"img_blank"		=> $img->blank,
											"img_desc"		=> $img->desc,
											"img_count"		=> $img_count,
											"i"				=> $i
										);
										$this->echo_img( $args );
										
										$i++;
									}
								}
							
							else:
								$this->echo_img();	
								
							endif;
							?>
							
						</tbody>
					</table>
					<p class="submit"><input type="submit" class="button button-primary" id="submit" name="submit" value="Enregistrer les modifications"></p>
				</form>
				
				<?php // Afficher la liste
				else : ?>
				<table class="widefat">
					<thead>
						<tr>
							<th>Titre du banner</th>
							<th>Nombre d'images</th>
							<?php if ( $this->as_max_rights() ) : ?>
							<th>Slug</th>
							<?php endif; ?>
							<th></th>
						</tr>
					</thead>
					<tbody>
						<?php
							$i=0;
							foreach( $options as $banner ) :
								$alt	= is_int($i/2) ? ' class="alternate"' : '';
								$i++;;
						?>
						<tr<?php echo $alt; ?>>
							<td>
								<a href="<?php echo add_query_arg( array('b' => $banner->slug ) ); ?>"><?php echo $banner->title; ?></a>
							</td>
							<td>
								
							</td>
							<?php if ( $this->as_max_rights() ) : ?>
							<td><?php echo $banner->slug; ?></td>
							<?php endif; ?>
							<td>
								<form action="" method="post">
									<input type="hidden" name="action" value="del">
									<input type="hidden" name="slug" value="<?php echo $banner->slug; ?>">
									<input type="submit" class="button button-default alignright" value="Supprimer">
								</form>
							</td>
						</tr>
						<?php endforeach; ?>
					</tbody>
				</table>
				
				<br>
				<?php endif; ?>
			<?php endif; ?>
			
			
			<?php // Ajouter
			if ( $this->as_max_rights() && empty( $banner_data ) ) : ?>
			<form action="" method="post">
				<input type="hidden" value="add" name="action">
				<p class="submit"><input type="text" id="title" name="title" class="regular-text" value="" placeholder="Titre" > <input id="submit" class="button button-primary" type="submit" value="Ajouter une bannière" name="submit"></p>
			</form>
			<?php endif; ?>
		</div>
		<?php
	}
	function echo_img( $args="" )
	{
		if ( !empty( $args ) && !is_array( $args ) )
			return;
		
		$title		= "Ajouter une image";
		$i			= 0;
		$img_count	= 0;
		$img_id		= "";
		$img_elem	= "";
		$img_title	= "";
		$img_url	= "";
		$img_blank	= "";
		$img_desc	= "";
		
		if ( !empty( $args ) && is_array( $args ) )
		{
			$title		= "Modifier l'image";
			$i			= $args["i"];
			$img_id		= strval( $args["img_id"] );
			$img_elem	= wp_get_attachment_image_src( $img_id, 'mgrm_'.$this->slug );
			$img_elem	= '<br><br><img src="'.$img_elem[0].'" width="100%" id="img_'.$img_id.'">';
			$img_title	= stripslashes( $args["img_title"] );
			$img_url	= stripslashes( $args["img_url"] );
			$img_blank	= checked( "1", $args["img_blank"], false) ? ' checked="checked"' : '';
			$img_desc	= stripslashes( $args["img_desc"] );
			$img_count	= $args["img_count"];
		}
		
		$class_alt	= is_int( $i/2 ) ? ' class="alternate"' : '';
		$class_prev	= $i==0 ? ' disabled' : '';
		$class_next	= $i==$img_count-1 ? ' disabled' : '';
		
		?>
		<tr<?php echo $class_alt; ?>>
			<td width="20" style="vertical-align:middle">
				<span class="dashicons dashicons-arrow-up-alt2<?php echo $class_prev; ?>" title="Placer l'image à la position précédente"></span>
				<hr>
				<span class="dashicons dashicons-arrow-down-alt2<?php echo $class_next; ?>" title="Placer l'image à la position suivante"></span>
			</td>
			<td style="vertical-align:middle">
				<table width="100%">
					<tr>
						<td colspan="2">
							<h3><?php echo $title; ?></h3>
							<input type="button" class="button media-browser" value="Sélectionner une image">
							<input type="hidden" value="<?php echo $img_id; ?>" id="img<?php echo strval( $i ); ?>_id" name="img<?php echo strval( $i ); ?>_id">
							<?php echo $img_elem; ?>
						</td>
					</tr>
					<tr>
						<td>
							<p><input type="text" id="img<?php echo strval( $i ); ?>_title" name="img<?php echo strval( $i ); ?>_title" class="large-text" value="<?php echo $img_title; ?>" placeholder="Titre de l'image"></p>
							<p><input type="text" id="img<?php echo strval( $i ); ?>_url" name="img<?php echo strval( $i ); ?>_url" class="large-text" value="<?php echo $img_url; ?>" placeholder="http://...">
								<input type="checkbox" id="img<?php echo strval( $i ); ?>_blank" name="img<?php echo strval( $i ); ?>_blank" value="1"<?php echo $img_blank; ?>><label for="img<?php echo strval( $i ); ?>_blank"><small>Ouvrir dans une nouvelle fenêtre</small></label></p>
						</td>
						<td>
							<?php wp_editor( $img_desc, 'img'.strval( $i ).'_text', array( 'teeny' => true, 'media_buttons' => false, 'textarea_rows' => 5, 'textarea_name' => 'img'.strval( $i ).'_desc' ) ); ?>
						</td>
					</tr>
					<tr>
						<td colspan="2"><a href="" class="img-remove">Supprimer l'image</a></td>
					</tr>
				</table>
			</td>
		</tr>
		<?php
	}
	
	
	// Ajouter un banner
	function add_item()
	{
		//delete_option( 'mgrm_'.$this->slug );
		// Récupérer les données
		$options	= get_option( 'mgrm_'.$this->slug );
		$options	= json_decode( $options );
		
		$slug	= sanitize_title( $_POST['title'] );
		
		if ( empty( $slug ) )
		{
			return $this->admin_notice( 'error', 'notice_title_empty' );
		}
		
		if ( is_array( $options ) ) {
			foreach ( $options as $item )
			{
				if ( $item->slug == $slug )
				{
					return $this->admin_notice( 'error', 'notice_title_exists' );
				}
			}
		}
		
		if ( empty( $options ) )
		{
			$options	= array();
		}
		
		$banner			= new stdClass();
		$banner->slug	= $slug;
		$banner->title	= $_POST['title'];
		
		array_push( $options, $banner );
		
		$options	= json_encode( $options );
		update_option( 'mgrm_'.$this->slug, $options );
		
		return $this->admin_notice( 'updated', 'notice_added' ); 
	}
	
	
	// Supprimer un banner
	function del_item()
	{
		// Récupérer les données
		$options	= get_option( 'mgrm_'.$this->slug );
		$options	= json_decode( $options );
		
		$slug			= $_POST['slug'];
		$action			= $_POST['action'];
		$options_del	= array();
		
		if ( $action == "del" )
		{
			foreach( $options as $item )
			{
				if ( $item->slug != $slug )
				{
					array_push( $options_del, $item );
				}
			}
		}else{
			$options_del = $options;
		}
		
		$options	= json_encode( $options_del );
		update_option( 'mgrm_'.$this->slug, $options );
		
		return $this->admin_notice( 'updated', 'notice_deleted' );
	}
	
	
	// Mettre à jour les infos d'un banner
	function update_changes()
	{
		
		// Récupérer les données
		$options	= get_option( 'mgrm_'.$this->slug );
		$options	= json_decode( $options );
		
		// Données envoyée
		$post_count	= count( $_POST );
		$slug		= $_POST['slug'];
		
		$images		= array();
		
		for ( $i=0; $i<$post_count; $i++ )
		{
			if ( isset( $_POST['img'.$i.'_id'] ) && !empty( $_POST['img'.$i.'_id'] ) )
			{
				$img = new stdClass();
				$img->id 		= $_POST['img'.$i.'_id'];
				$img->title	= $_POST['img'.$i.'_title'];
				$img->url		= $_POST['img'.$i.'_url'];
				$img->blank	= isset( $_POST['img'.$i.'_blank'] ) ? $_POST['img'.$i.'_blank'] : '';
				$img->desc	= $_POST['img'.$i.'_desc'];
				
				$images[] = $img;
			}
		}

		$images = (object)$images;
		
		// Récupérer les données à mettre à jour
		foreach( $options as $key => $item )
		{
			if ( $item->slug == $slug )
			{
				// Enregistrer les paramètres de visibilité
				if ( !isset( $options[$key]->show_on ) || !is_object( $options[$key]->show_on ) )
				{
					$options[$key]->show_on	= new stdClass();
				}
				
				$options[$key]->show_on->{$this->cur_lng}->all = 0;
				if ( isset( $_POST['show_on_all'] ) )
				{
					$options[$key]->show_on->{$this->cur_lng}->all = $_POST['show_on_all'];
				}
				
				$options[$key]->show_on->{$this->cur_lng}->hp = 0;
				if ( isset( $_POST['show_on_hp'] ) )
				{
					$options[$key]->show_on->{$this->cur_lng}->hp = $_POST['show_on_hp'];
				}
				
				$options[$key]->show_on->{$this->cur_lng}->pid = 0;
				if ( isset( $_POST['show_on_pid'] ) )
				{
					$options[$key]->show_on->{$this->cur_lng}->pid = $_POST['show_on_pid'];
				}
				
				$options[$key]->show_on->{$this->cur_lng}->cid = 0;
				if ( isset( $_POST['show_on_cid'] ) )
				{
					$options[$key]->show_on->{$this->cur_lng}->cid = $_POST['show_on_cid'];
				}
				
				
				// Ajouter les images
				if ( !isset( $options[$key]->images ) || !is_object( $options[$key]->images ) )
				{
					$options[$key]->images	= new stdClass();
				}
				$options[$key]->images->{$this->cur_lng} = $images;
				
				break;
			}
		}
		
		/*
		print "<pre>";
		print_r( $options );
		print "</pre>";
		*/
		
		// Enregistrer
		$options	= json_encode( $options );
		update_option( 'mgrm_'.$this->slug, $options );
		
	}
	
	
	// Messages à afficher dans l'admin
	// $type	: updated, error
	function admin_notice( $type="updated", $slug="" )
	{
		$notice = "";
		
		if ( isset( $this->{$slug} ) )
		{
			$notice	= $this->{$slug};
			
			if ( $type	== "error" )
			{
				$notice	= '<div class="error">'.$notice.'</div>';
				
			}else{
				$notice	= '<div class="updated">'.$notice.'</div>';
			}
		}
		
		return $notice;
	}
	
	
	// Vérifie les droits d'un utilisateurs pour afficher des options supplémentaires
	function as_max_rights ()
	{
		if ( current_user_can( $this->max_rights ) )
		{
			return true;
		}
		
		return false;
	}
	
	
	// ------------------------------------------------------------------------------------------------------------------------------------------------------
	
	
	// Ajoute le js et css
	function front_js_css()
	{		
		$path = get_template_directory_uri().'/custom/'.$this->slug;
		
		wp_enqueue_style( 'mgrm_'.$this->slug, $path.'/css/front.css', array(), null );
	}
	
	function banner_display()
	{
		global $post, $page;
		
		// Catégorie
		$cid	= null;
		if ( is_category() )
		{
			$the_cat	= get_the_category();
		}else if ( isset( $post->post_type ) && $post->post_type == "post" )
		{
			$the_cat	= get_the_category( $post->ID );
		}
		if ( isset( $the_cat[0] ) && !empty( $the_cat[0] ) )
		{
			$cid	= isset( $the_cat[0]->term_id ) ? $the_cat[0]->term_id : 0;
		}
		
		// Page
		$pid	= null;
		if ( is_page() )
		{
			$pid	= $post->ID;
		}
		
		// Récupérer les données
		$data	= get_option( 'mgrm_'.$this->slug );
		$data	= json_decode( $data );
		
		//print "<pre>";
		//print_r( $data );
		//print "</pre>";
		
		if ( !empty( $data ) )
		{
			foreach( $data as $banner )
			{
				if ( isset( $banner->show_on ) && isset( $banner->show_on->{$this->cur_lng} ) )
				{
					
					if ( $banner->show_on->{$this->cur_lng}->all == 1
					|| ( $banner->show_on->{$this->cur_lng}->hp == 1 && ( is_home() || is_front_page() ) ) // Home
					|| ( $pid != null && $banner->show_on->{$this->cur_lng}->pid == $pid ) // Page
					|| ( $cid != null && $banner->show_on->{$this->cur_lng}->cid == $cid ) ) // Category
					{
						if ( !empty( $banner->images->{$this->cur_lng} ) )
						{
						?>
						<div id="<?php echo $this->slug.'-'.$banner->slug; ?>" class="<?php echo $this->slug; ?>">
							
							<div id="carousel-example-generic" class="carousel carousel-fade slide" data-ride="carousel">
								<div class="carousel-inner" role="listbox">
									<?php
									$i = 0;
									foreach( $banner->images->{$this->cur_lng} as $img )
									{
										$active	= $i == 0 ? ' active' : '';
										
										//print "<pre>";
										//print_r( $img );
										//print "</pre>";
										
										$img_id		= $img->id;
										$img_elem	= wp_get_attachment_image( $img_id, 'mgrm_'.$this->slug );
										$title		= stripcslashes( $img->title );
										$caption	= wpautop( stripslashes( $img->desc ) );
										
										$i++;
									?>
									<div class="item<?php echo $active; ?>">
										<?php echo $img_elem; ?>
										<div class="carousel-caption container">
											<?php echo !empty( $title ) ? '<p class="content-title">'.$title.'</p>' : ''; ?>
											<?php echo $caption; ?>
										</div>
									</div>
									<?php } ?>
								</div>
							</div>
							<div class="mask"></div>
						</div>
						<?php
						}
					}
				}
			}
		}
	}
	
	
	function get_banner($slug="")
	{
		if ( empty( $slug ) )
			return;
		
		// Récupérer les données
		$options	= get_option( 'mgrm_'.$this->slug );
		$options	= json_decode( $options );
		
		$banner_exists	= false;
		$banner_content	= "";
		
		if ( !empty( $options ) )
		{
			
			foreach( $options as $banner )
			{
				// $banner->slug
				// $banner->title
				// $banner->images
				
				if ( $banner->slug == $slug )
				{
					$banner_exists	= true;
					
					$banner_images		= "";
					$banner_captions	= "";
					
					$img_i	= 0;
					
					if ( isset( $banner->images->{$this->cur_lng} ) && !empty( $banner->images->{$this->cur_lng} ) )
					{
					
						foreach( $banner->images->{$this->cur_lng} as $image )
						{
							// $image->id
							// $image->title
							// $image->url
							// $image->blank
							// $image->desc
							
							$image_content		= "";
							$caption_content	= "";
							
							if ( !empty( $image->id ) )
							{
								$image_content	.= wp_get_attachment_image( $image->id, 'mgrm_'.$this->slug );
							}
							
							if ( !empty( $image->id ) && !empty( $image->url ) )
							{
								$target	= "";
								
								if ( !empty( $image->blank ) )
								{
									$target	= ' target="_blank"';
								}
								
								$image_content	= '<a href="'.$image->url.'"'.$target.'>'.$image_content.'</a>';
							}
							
							// ---
							
							if ( !empty( $image->title ) )
							{
								$caption_content	.= '<p class="post-title">'.$image->title.'</p>';
							}
							if ( !empty( $image->desc ) )
							{
								$caption_content	.= '<div class="desc">'.stripslashes( wpautop( $image->desc ) ).'</div>';
							}
							
							if ( !empty( $caption_content ) )
							{
								$image_content .= '<div class="carousel-caption">'.$caption_content.'</div>';
							}
							
							// ---
							
							if ( !empty( $image_content ) )
							{
								$active		= $img_i == 0 ? " active" : '';
								$banner_images .= '<div class="item'.$active.'">'.$image_content.'</div>';
							}
							
							$img_i++;
						}
					
						$banner_content	= '
						<div id="banner-'.$banner->slug.'" class="carousel slide carousel-fade" data-ride="carousel">
							<div class="carousel-inner" role="listbox">
								'.$banner_images.'
							</div>
						</div>
						<script type="text/javascript">
							jQuery(document).ready(function($) {
								$("#banner-'.$banner->slug.'").carousel();
							});
						</script>';
					}
				}
			}
		}
		
		if ( $banner_exists )
		{	
			echo $banner_content;
		}
		/*print "<pre>";
		print_r( $options );
		print "</pre>";*/
	}
	
	function front_nivo_slider()
	{
		$slug	= "nivo-slider";
		
		$path = get_template_directory_uri().'/js/'.$slug;
			
			wp_enqueue_style( 'mgrm_'.$slug, $path.'/themes/default/default.css' );
			wp_enqueue_style( 'mgrm_'.$slug, $path.'/css/nivo-slider.css' );
			
			wp_enqueue_script('jquery');
			
			wp_enqueue_script( 'mgrm_'.$slug, $path.'/js/jquery.nivo.slider.pack.js', array('jquery'), null, false );
	}
}